---
title: '[릴리즈노트] 2024-09-05 관리자콘솔 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 계정정보
  - 로그아웃
  - 메뉴변경
  - 업데이트
  - 관리자콘솔
datetime: 2025-02-13T06:02:32.259Z
---

<Callout title="2024년 9월 5일 관리자콘솔 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

✔️ 좌측 메뉴 영역이 새롭게 변경되었습니다.



- \[메뉴 접기]
  - 메뉴 접기 아이콘을 클릭하여 좌측 메뉴 영역을 접을 수 있습니다.
  - 메뉴가 접힌 상태에서 한번 더 클릭하는 경우 다시 메뉴를 펼칠 수 있습니다.
- \[전자결제 신청]
  - 전자결제 신청을 원하시는 경우 좌측 메뉴 영역 하단의 \[전자결제 신청]을 클릭해 주세요.
- \[로그아웃]
  - 좌측 메뉴 영역 상단의 \[계정 정보]를 클릭한 후 \[로그아웃]을 클릭해 주세요.

#### [\[관리자콘솔 릴리즈노트\] 2025-09-05 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2024-09-05)
